@@ -4,7 +4,7 @@ use warnings;
 
 package Gentoo::Overlay::Exceptions;
 
-our $VERSION = '2.001001';
+our $VERSION = '2.001002';
 
 # ABSTRACT: A custom Exception class for Gentoo which also has warning-style semantics instead of failure
 
@@ -122,7 +122,7 @@ with( 'Throwable', 'StackTrace::Auto', );
 sub message {
   my ($self) = @_;
   return try {
-    errf( $self->message_fmt, $self->payload )
+    errf( $self->message_fmt, $self->payload );
   }
   catch {
     sprintf '%s (error during formatting)', $self->message_fmt;
@@ -145,7 +145,7 @@ Gentoo::Overlay::Exceptions - A custom Exception class for Gentoo which also has
 
 =head1 VERSION
 
-version 2.001001
+version 2.001002
 
 =for Pod::Coverage BUILDARGS
 
@@ -157,7 +157,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2017 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
